@@ -23,9 +23,11 @@ def rh2mixr(RH,p,T):
     es = esat(T)
     return Mw/Md*RH/100.*es/(p-RH/100.*es)*1000.
 
-# conversion mixing ratio to specific humidity
+# conversion mixing ratio to specific humidity (always kg/kg)
 def mixr2sh(W):
-    return W/(1.+W/1000.)
+    return W/(1.+W)
+def sh2mixr(qv):
+    return qv/(1.-qv)
 def ea2mixr(P,ea):
     return 0.622* ea/(P-ea)
 
